@@ -35,6 +35,7 @@ sub connect {
     my $write_timeout= delete $attr->{cass_write_timeout};
     my $connect_timeout= delete $attr->{cass_connect_timeout}; #XXX
     my $request_timeout= delete $attr->{cass_request_timeout};
+    my $tls= delete $attr->{cass_tls};
     if ($read_timeout || $write_timeout) {
         if ($request_timeout) {
             warn 'Ignoring read_timeout and write_timeout settings, as request_timeout is passed';
@@ -54,6 +55,7 @@ sub connect {
         cql_version => $cql_version,
         request_timeout => $request_timeout,
         anyevent => 0,
+        tls => $tls,
     );
     my ($error)= $client->call_connect;
     return $drh->set_err($DBI::stderr, "Can't connect to $dr_dsn: $error") if $error;
